@@ -13,9 +13,11 @@ def hexdump(packet, dump=False, to_list=False):
             return chr(j)
 
     def split(obj, num):
-        return [obj[start:start + num]
-                for start in range(0, len(obj), num)
-                if obj[start:start + num]]
+        return [
+            obj[start : start + num]
+            for start in range(0, len(obj), num)
+            if obj[start : start + num]
+        ]
 
     def __process_hexdump(ppacket):
         row = []
@@ -24,8 +26,7 @@ def hexdump(packet, dump=False, to_list=False):
             if len(line) < 16:
                 line += ["  " for _ in range(16 - len(line))]
 
-            row.append("%03x0   %s   %s" %
-                       (i, ' '.join(line), ''.join(console_char)))
+            row.append("%03x0   %s   %s" % (i, " ".join(line), "".join(console_char)))
         return row
 
     def __alternative_process_hexdump(ppacket):
@@ -35,8 +36,7 @@ def hexdump(packet, dump=False, to_list=False):
             if len(line) < 16:
                 line += ["  " for _ in range(16 - len(line))]
 
-            row.append("%03x0   %s   %s" %
-                       (i, ' '.join(line), ''.join(console_char)))
+            row.append("%03x0   %s   %s" % (i, " ".join(line), "".join(console_char)))
         return row
 
     def __third_process_hexdump(ppacket):
@@ -45,8 +45,7 @@ def hexdump(packet, dump=False, to_list=False):
             console_char = [to_char(x) for x in line]
             if len(line) < 16:
                 line += "".join(["  " for _ in range(16 - len(line))])
-            row.append("%03x0   %s   %s" %
-                       (i, ' '.join(line), ''.join(console_char)))
+            row.append("%03x0   %s   %s" % (i, " ".join(line), "".join(console_char)))
         return row
 
     try:
